searchData={"items":[{"type":"module","title":"Pile","doc":"This library allows representing HTML in Elixir. It uses tuples to represent elements, and maps to represent element attributes:\n  \n    iex> {:html,\n    ...>   {:head, [\n    ...>     {:title, \"Hello World\"},\n    ...>     {:link, %{rel: \"stylesheet\", href: \"...\"}},    \n    ...>   ]}\n    ...> }\n    ...> |> Pile.to_html()\n    ...> \n    \"   Hello World    \"\n  \n  See `Pile.to_html/2` for more details about the syntax","ref":"Pile.html"},{"type":"function","title":"Pile.to_html/2","doc":"Converts a tuple or list of tuples into an HTML string","ref":"Pile.html#to_html/2"},{"type":"function","title":"Options: - Pile.to_html/2","doc":"- `pretty`: Passing `true` causes the HTML output to be pretty-printed. Defaults to `false`.\n- `doctype`: Prepend the `<!DOCTYPE html>` to the resulting string. Defaults to `false`.\n- `iodata`: Return the HTML as iodata. Defaults to `false`.","ref":"Pile.html#to_html/2-options"},{"type":"function","title":"Syntax: - Pile.to_html/2","doc":"A tuple begining with an atom represents an HTML element:\n\n    iex> {:div} |> Pile.to_html()\n    \"  \"\n\nAn element can have a child:\n    \n    iex> {:div, {:p}} |> Pile.to_html()\n    \"    \"\n\nIf an element has more than one child, place the children in a list:\n\n    iex> {:div, [{:p}, {:p}]} |> Pile.to_html()\n    \"      \"\n\nStrings are HTML-escaped, then rendered as text:\n    \n    iex> {:div, \"hello\"} |> Pile.to_html()\n    \" hello \"\n    iex> {:div, \" \"} |> Pile.to_html()\n    \" &lt;span&gt; \"\n\nTo bypass HTML escaping, using the special `_rawtext` element:\n    \n    iex> {:div, {:_rawtext, \" \"}} |> Pile.to_html()\n    \"   \"\n\nAn element may have attributes. These are represented as a map, and if present must come right after the element name:\n\n    iex> {:div, %{class: \"container\"}} |> Pile.to_html()\n    \"  \"\n    iex> {:div, %{class: \"container\"}, [\"foo\", {:p}]} |> Pile.to_html()\n    \" foo   \"\n\nAn attribute with a boolean value is treated as an [HTML boolean attribute](https://developer.mozilla.org/en-US/docs/Glossary/Boolean/HTML)\n\n    iex> {:div, %{readonly: true}} |> Pile.to_html()\n    \"  \"\n    iex> {:div, %{readonly: false}} |> Pile.to_html()\n    \"  \"","ref":"Pile.html#to_html/2-syntax"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}